==> haskell-sha-1.6.4.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sha.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SHA
version: 1.6.4.4
id: SHA-1.6.4.4-1zvOUgVKaQx7KvqAhOzZXy
key: SHA-1.6.4.4-1zvOUgVKaQx7KvqAhOzZXy
license: BSD3
maintainer: Adam Wick <awick@galois.com>,
            Raphael Javaux <raphaeljavaux@gmail.com>
stability: stable
synopsis: Implementations of the SHA suite of message digest functions
description:
    This library implements the SHA suite of message digest functions,
    according to NIST FIPS 180-2 (with the SHA-224 addendum), as well
    as the SHA-based HMAC routines. The functions have been tested
    against most of the NIST and RFC test vectors for the various
    functions. While some attention has been paid to performance,
    these do not presently reach the speed of well-tuned libraries,
    like OpenSSL.
category: Cryptography, Codec
author: Adam Wick <awick@galois.com>, Brian Lewis <brian@lorf.org>
exposed: True
indefinite: False
exposed-modules:
    Data.Digest.Pure.SHA
abi: e2a015fdc5d143c2552d0192c0b893ff
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/SHA-1.6.4.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/SHA-1.6.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/SHA-1.6.4.4
hs-libraries: HSSHA-1.6.4.4-1zvOUgVKaQx7KvqAhOzZXy
depends:
    array-0.5.2.0 base-4.10.1.0 binary-0.8.5.1 bytestring-0.10.8.2
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-sha/html/SHA.haddock
haddock-html: /usr/share/doc/haskell-sha/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sha-1.6.4.4-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sha.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SHA
version: 1.6.4.4
id: SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
key: SHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
license: BSD-3-Clause
maintainer: Adam Wick <awick@galois.com>,
            Raphael Javaux <raphaeljavaux@gmail.com>
author: Adam Wick <awick@galois.com>, Brian Lewis <brian@lorf.org>
stability: stable
synopsis: Implementations of the SHA suite of message digest functions
description:
    This library implements the SHA suite of message digest functions,
    according to NIST FIPS 180-2 (with the SHA-224 addendum), as well
    as the SHA-based HMAC routines. The functions have been tested
    against most of the NIST and RFC test vectors for the various
    functions. While some attention has been paid to performance,
    these do not presently reach the speed of well-tuned libraries,
    like OpenSSL.
category: Cryptography, Codec
abi: 7fdfeaf1e3416ffd434c90cf824fb303
exposed: True
exposed-modules:
    Data.Digest.Pure.SHA
import-dirs: /usr/lib/ghc-8.4.3/site-local/SHA-1.6.4.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/SHA-1.6.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/SHA-1.6.4.4
hs-libraries: HSSHA-1.6.4.4-J97i4k52krALB5u9VxmQ73
depends:
    array-0.5.2.0 base-4.11.1.0 binary-0.8.5.1 bytestring-0.10.8.2
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-sha/html/SHA.haddock
haddock-html: /usr/share/doc/haskell-sha/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
